==> haskell-kvitable-1.1.0.1-30-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-kvitable.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 kvitable
version:              1.1.0.1
visibility:           public
id:                   kvitable-1.1.0.1-5Pxs8Zt9vm16FdZM4MvpJe
key:                  kvitable-1.1.0.1-5Pxs8Zt9vm16FdZM4MvpJe
license:              ISC
copyright:            Kevin Quick, 2021-2022
maintainer:           kquick@galois.com
author:               Kevin Quick
homepage:             https://github.com/kquick/kvitable
synopsis:             Key/Value Indexed Table container and formatting library
description:

    Allows creation of a table from a set of of Key+Value Indices.
    This differs from the standard '\''Map'\'' structure in that the '\''Map'\''
    simply indexes by value but the KVI table indexes by a
    heterogeneous list of keys along with their associated values.
    This effectively creates an N-dimensional table, where
    @N=Product(Count(Values[key]))@.  The table contents can be sparse.

    This library also provides the ability to format multi-dimensional
    data in a table presentation.  The table is automatically formatted
    and can be output in a number of different styles (ascii, html,
    etc.)

    Multi-dimensional data is more difficult to represent than simple
    two-dimensional data; this package provides the ability to select
    which dimensions should be represented as sub-rows and which
    dimensions should be represented as sub-columns.  See the README
    for examples

category:             Text
abi:                  2a855e03c0cb0eedb715f05a4a834116
exposed:              True
exposed-modules:
    Data.KVITable Data.KVITable.Internal.Helpers Data.KVITable.Render
    Data.KVITable.Render.ASCII Data.KVITable.Render.HTML
    Data.KVITable.Render.Internal

import-dirs:          /usr/lib/ghc-9.4.8/site-local/kvitable-1.1.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/kvitable-1.1.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/kvitable-1.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-kvitable
hs-libraries:         HSkvitable-1.1.0.1-5Pxs8Zt9vm16FdZM4MvpJe
depends:
    base-4.17.2.1 containers-0.6.7
    lucid-2.11.20230408-JEaiKD20n20C1EZEpxqFYz
    microlens-0.4.14.0-71jOCsiFFF8LaovsPy6HDt
    named-text-1.2.1.0-HH8OIA7F4p4HsNCjfbtTvj
    sayable-1.2.5.0-IWrQn2p5whQHoR1sbnQE75 text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-kvitable/html/kvitable.haddock
haddock-html:         /usr/share/doc/haskell-kvitable/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-kvitable-1.1.0.1-31-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-kvitable.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 kvitable
version:              1.1.0.1
visibility:           public
id:                   kvitable-1.1.0.1-L87TvIRph86CWgbfV7lodm
key:                  kvitable-1.1.0.1-L87TvIRph86CWgbfV7lodm
license:              ISC
copyright:            Kevin Quick, 2021-2022
maintainer:           kquick@galois.com
author:               Kevin Quick
homepage:             https://github.com/kquick/kvitable
synopsis:             Key/Value Indexed Table container and formatting library
description:

    Allows creation of a table from a set of of Key+Value Indices.
    This differs from the standard '\''Map'\'' structure in that the '\''Map'\''
    simply indexes by value but the KVI table indexes by a
    heterogeneous list of keys along with their associated values.
    This effectively creates an N-dimensional table, where
    @N=Product(Count(Values[key]))@.  The table contents can be sparse.

    This library also provides the ability to format multi-dimensional
    data in a table presentation.  The table is automatically formatted
    and can be output in a number of different styles (ascii, html,
    etc.)

    Multi-dimensional data is more difficult to represent than simple
    two-dimensional data; this package provides the ability to select
    which dimensions should be represented as sub-rows and which
    dimensions should be represented as sub-columns.  See the README
    for examples

category:             Text
abi:                  e355a534779e34af83f14463542bcb25
exposed:              True
exposed-modules:
    Data.KVITable Data.KVITable.Internal.Helpers Data.KVITable.Render
    Data.KVITable.Render.ASCII Data.KVITable.Render.HTML
    Data.KVITable.Render.Internal

import-dirs:          /usr/lib/ghc-9.4.8/site-local/kvitable-1.1.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/kvitable-1.1.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/kvitable-1.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-kvitable
hs-libraries:         HSkvitable-1.1.0.1-L87TvIRph86CWgbfV7lodm
depends:
    base-4.17.2.1 containers-0.6.7
    lucid-2.11.20230408-9Zk4HMmN9jeG9iNecblDx5
    microlens-0.4.14.0-71jOCsiFFF8LaovsPy6HDt
    named-text-1.2.1.0-LuFW9KSEPza1RKt5npyBQr
    sayable-1.2.5.0-7GBcWAGeRjBTE1lclU4Hh text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-kvitable/html/kvitable.haddock
haddock-html:         /usr/share/doc/haskell-kvitable/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
